@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-a2i-runtime service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/literals/)
 
 Usage::
 
@@ -24,7 +24,9 @@ __all__ = (
     "HumanLoopStatusType",
     "ListHumanLoopsPaginatorName",
     "SortOrderType",
+    "AugmentedAIRuntimeServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -33,6 +35,7 @@ ContentClassifierType = Literal["FreeOfAdultContent", "FreeOfPersonallyIdentifia
 HumanLoopStatusType = Literal["Completed", "Failed", "InProgress", "Stopped", "Stopping"]
 ListHumanLoopsPaginatorName = Literal["list_human_loops"]
 SortOrderType = Literal["Ascending", "Descending"]
+AugmentedAIRuntimeServiceName = Literal["sagemaker-a2i-runtime"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -66,6 +69,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -320,4 +324,16 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_human_loops"]
