@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-a2i-runtime service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/type_defs/)
 
 Usage::
 
@@ -13,7 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence, Union
+from typing import Dict, List, Sequence, Union
+
+from typing_extensions import NotRequired
 
 from .literals import ContentClassifierType, HumanLoopStatusType, SortOrderType
 
@@ -31,6 +33,7 @@ __all__ = (
     "HumanLoopInputTypeDef",
     "HumanLoopOutputTypeDef",
     "HumanLoopSummaryTypeDef",
+    "ListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
     "ListHumanLoopsRequestRequestTypeDef",
     "ListHumanLoopsResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -102,6 +105,31 @@ HumanLoopSummaryTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
+    "_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
+    {
+        "FlowDefinitionArn": str,
+    },
+)
+_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
+    "_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
+    {
+        "CreationTimeAfter": Union[datetime, str],
+        "CreationTimeBefore": Union[datetime, str],
+        "SortOrder": SortOrderType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListHumanLoopsRequestListHumanLoopsPaginateTypeDef(
+    _RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
+    _OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListHumanLoopsRequestRequestTypeDef = TypedDict(
     "_RequiredListHumanLoopsRequestRequestTypeDef",
     {
@@ -152,7 +180,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
